package bucky.test;

import org.tigris.subversion.javahl.DirEntry;
import org.tigris.subversion.javahl.SVNClient;

/**
 * Test program that reads the contents of some individual files. It causes heavy
 * use of sockets since each file being read use a new socket.
 */
public class Main
{
	private SVNClient m_client;

	public static void main(String[] args)
	{
		Main main = new Main();
		main.setUp();
		try
		{
			main.run();
		}
		catch(Throwable t)
		{
			t.printStackTrace();
		}
		finally
		{
			main.tearDown();
		}
	}

	public void setUp()
	{
		m_client = new SVNClient();
	}

	public void tearDown()
	{
		m_client.dispose();
	}

	static String s_repo = "svn://dev.eclipse.org/svnroot/technology/org.eclipse.buckminster/trunk";

	void run() throws Exception
	{
		DirEntry[] projDirs = m_client.list(s_repo, null, false);
		int top = projDirs.length;

		// Five project folders should be enough to prove the point
		//
		if(top > 5)
			top = 5;

		for(int idx = 0; idx < top; ++idx)
		{
			DirEntry projDir = projDirs[idx];
			if(projDir.getSize() > 0)
				continue;

			System.out.println("Project folder: " + projDir.getPath());
			String projectURL = s_repo + '/' + projDir.getPath();
			for(DirEntry entry : m_client.list(projectURL, null, false))
			{
				if(entry.getSize() == 0)
					continue;

				System.out.println("Reading file: " + entry.getPath());
				m_client.fileContent(projectURL + '/' + entry.getPath(), null);
			}
		}
	}
}
